@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -575,4 +575,21 @@ public class LafWidgetUtilities {
 		return (SwingUtilities.getAncestorOfClass(CellRendererPane.class, comp) != null);
 	}
 
+	/**
+	 * Tests UI threading violations on changing the state the specified
+	 * component.
+	 * 
+	 * @param comp
+	 *            Component.
+	 * @throws UiThreadingViolationException
+	 *             If the component is changing state off Event Dispatch Thread.
+	 */
+	public static void testComponentStateChangeThreadingViolation(Component comp) {
+		if (!SwingUtilities.isEventDispatchThread()) {
+			UiThreadingViolationException uiThreadingViolationError = new UiThreadingViolationException(
+					"Component state change must be done on Event Dispatch Thread");
+			uiThreadingViolationError.printStackTrace(System.err);
+			throw uiThreadingViolationError;
+		}
+	}
 }
