@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2005-2008 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
+ * Copyright (c) 2005-2009 Laf-Widget Kirill Grouchnikov. All Rights Reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -86,6 +86,8 @@ public class FadeTracker {
 	 */
 	private List<GlobalFadeTrackerCallback> globalCallbackList;
 
+	private boolean nothingTracked;
+
 	/**
 	 * Information on a single component under fade.
 	 * 
@@ -430,6 +432,8 @@ public class FadeTracker {
 				parent.repaint();
 			}
 		}
+
+		this.nothingTracked = (this.fadeInstances.size() == 0);
 	}
 
 	private void callbackCallFadeEnded(final FadeTrackerCallback fadeCallback,
@@ -591,6 +595,7 @@ public class FadeTracker {
 		}
 		map.put(cid, fadeState);
 		this.fadeInstances.put(fadeState.id, fadeKind);
+		this.nothingTracked = false;
 		if (DEBUG_MODE) {
 			System.out.println("Added (" + fadeState.id + ") on "
 					+ comp.getClass().getSimpleName() + "[" + componentId
@@ -1093,10 +1098,13 @@ public class FadeTracker {
 	 */
 	public boolean isTracked(Component comp, Comparable<?> componentId,
 			FadeKind fadeKind) {
-		ComponentId cid = new ComponentId(comp, componentId);
+		if (this.nothingTracked)
+			return false;
+
 		Map<ComponentId, FadeState> map = this.trackedComponents.get(fadeKind);
 		if (map == null)
 			return false;
+		ComponentId cid = new ComponentId(comp, componentId);
 		return map.containsKey(cid);
 	}
 
@@ -1128,11 +1136,14 @@ public class FadeTracker {
 			throw new IllegalArgumentException("Can't pass null fadeKind");
 		}
 
-		ComponentId cid = new ComponentId(comp, componentId);
+		if (this.nothingTracked)
+			return false;
+
 		Map<ComponentId, FadeState> map = this.trackedComponents.get(fadeKind);
 		if (map == null)
 			return false;
 
+		ComponentId cid = new ComponentId(comp, componentId);
 		FadeState fState = map.get(cid);
 		if (fState == null)
 			return false;
@@ -1201,11 +1212,14 @@ public class FadeTracker {
 			throw new IllegalArgumentException("Can't pass null fadeKind");
 		}
 
-		ComponentId cid = new ComponentId(comp, componentId);
+		if (this.nothingTracked)
+			return 0;
+
 		Map<ComponentId, FadeState> map = this.trackedComponents.get(fadeKind);
 		if ((map == null) || (map.size() == 0))
 			return 0;
 
+		ComponentId cid = new ComponentId(comp, componentId);
 		FadeState state = map.get(cid);
 		if (state == null)
 			return 0;
@@ -1294,11 +1308,14 @@ public class FadeTracker {
 			throw new IllegalArgumentException("Can't pass null fadeKind");
 		}
 
-		ComponentId cid = new ComponentId(comp, componentId);
+		if (this.nothingTracked)
+			return null;
+
 		Map<ComponentId, FadeState> map = this.trackedComponents.get(fadeKind);
 		if ((map == null) || (map.size() == 0))
 			return null;
 
+		ComponentId cid = new ComponentId(comp, componentId);
 		FadeState state = map.get(cid);
 		if (state == null)
 			return null;
